@@ -274,10 +274,29 @@ enum ie_type {
 	IE_TYPE_OWE_DH_PARAM                         = 256 + 32,
 	IE_TYPE_PASSWORD_IDENTIFIER                  = 256 + 33,
 	IE_TYPE_GLK_GCR_PARAMETER_SET                = 256 + 34,
+	IE_TYPE_HE_CAPABILITIES                      = 256 + 35,
+	IE_TYPE_HE_OPERATION                         = 256 + 36,
+	IE_TYPE_UORA_PARAMETER_SET                   = 256 + 37,
+	IE_TYPE_MU_EDCA_PARAMETER_SET                = 256 + 38,
+	IE_TYPE_SPATIAL_REUSE_PARAMETER_SET          = 256 + 39,
+	/* Reserved 40 */
+	IE_TYPE_NDP_FEEDBACK_REPORT_PARAMETER        = 256 + 41,
+	IE_TYPE_BSS_COLOR_CHANGE_ANNOUNCEMENT        = 256 + 42,
+	IE_TYPE_QUIET_TIME_PERIOD                    = 256 + 43,
 	IE_TYPE_VENDOR_SPECIFIC_REQUEST              = 256 + 44,
+	IE_TYPE_ESS_REPORT                           = 256 + 45,
+	IE_TYPE_OPS                                  = 256 + 46,
+	IE_TYPE_HE_BSS_LOAD                          = 256 + 47,
 	IE_TYPE_MAX_CHANNEL_SWITCH_TIME              = 256 + 52,
 	IE_TYPE_ESTIMATED_SERVICE_PARAMETERS_OUT     = 256 + 53,
 	IE_TYPE_OCI                                  = 256 + 54,
+	IE_TYPE_MULTIPLE_BSSID_CONFIGURATION         = 256 + 55,
+	/* Reserved 56 */
+	IE_TYPE_KNOWN_BSSID                          = 256 + 57,
+	IE_TYPE_SHORT_SSID_LIST                      = 256 + 58,
+	IE_TYPE_HE_6GHZ_BAND_CAPABILITIES            = 256 + 59,
+	IE_TYPE_UL_MU_POWER_CAPABILITIES             = 256 + 60,
+	/* Reserved 61 - 87 */
 	IE_TYPE_MSCS_DESCRIPTOR                      = 256 + 88,
 	IE_TYPE_SUPPLEMENTAL_CLASS_2_CAPABILITIES    = 256 + 90,
 	IE_TYPE_REJECTED_GROUPS                      = 256 + 92,
@@ -663,3 +682,5 @@ int ie_parse_owe_transition(const void *data, size_t len,
 				struct ie_owe_transition_info *info);
 
 int ie_parse_oci(const void *data, size_t len, const uint8_t **oci);
+
+bool ie_validate_he_capabilities(const void *data, size_t len);
